#
# spec file for package grip
#
# Copyright (c) 2023 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           grip
Version:        4.2.4
Release:        1699.2.pm.4
Summary:        An Audio CD Ripping Application
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Grabbers
URL:            https://sourceforge.net/projects/grip
Source:         https://sourceforge.net/projects/grip/files/%{version}/%{name}-%{version}.tar.gz
Patch0:         grip-configure.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cdparanoia-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  gnome-doc-utils
BuildRequires:  help2man
BuildRequires:  id3lib-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcurl)
Requires:       cdparanoia
Requires:       flac
Requires:       lame
Requires:       vorbis-tools
Requires:       wavpack
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
Recommends:     %{name}-lang = %{version}
Obsoletes:      grip2 < %{version}
Provides:       grip2 = %{version}

%description
Grip automates the process of extracting audio CD data, encoding it
with Ogg Vorbis, and naming the resulting files using CDDB data. It
also allows creation of MP3 and FLACS files if you have an MP3
repectivly FLAC encoder installed.

%lang_package

%prep
%setup -q
%patch -P0 -p1

%build
autoreconf -fiv
%configure
make %{?_smp_mflags}

help2man -N -l -s 1  src/grip > grip.1
sed -ri '/^\.TH/ { s/GNOME grip/grip/; s/GNOME/grip/}' grip.1
sed -ri '/manual page for GNOME/ { s/GNOME grip/grip/; s/GNOME/grip/}' grip.1

%install
%make_install
echo DocPath=grip >> %{buildroot}%{_datadir}/applications/grip.desktop
%suse_update_desktop_file -r grip AudioVideo AudioVideoEditing
%find_lang grip
%fdupes %{buildroot}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%license COPYING COPYING-LGPL
%doc ABOUT-NLS AUTHORS CREDITS ChangeLog README TODO
%{_bindir}/grip
%{_datadir}/applications/grip.desktop
%dir %{_datadir}/apps
%dir %{_datadir}/apps/solid
%dir %{_datadir}/apps/solid/actions
%dir %{_datadir}/solid
%dir %{_datadir}/solid/actions
%{_datadir}/apps/solid/actions/grip-audiocd.desktop
%{_datadir}/solid/actions/grip-audiocd.desktop
%{_datadir}/icons/hicolor/*/apps/grip.*
%{_datadir}/pixmaps/grip*.png
%{_mandir}/man1/grip.1%{?ext_man}

%files lang -f grip.lang

%changelog
* Mon Sep 30 2024 Dr. Werner Fink <werner@suse.de>
- Modernize usage of %%patch macro
* Wed Jan  4 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 4.2.4
  * Translation updates: Hungarian
  * New translation: Romanian
* Thu Sep  9 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 4.2.3
  * Patch from Christian Weisgerber: Store fgetc() return value in
    int for comparison with EOF
  * Translation updates: Italian
- Update to version 4.2.2
  * Patch from D. J. Slattery: fix crash on startup due to
    invalid pointer
- Update to version 4.2.1
  * Translation updates: Italian
  * Update documentation, IRC moving from Freenode to Libera
* Thu Feb 11 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 4.2.0
  * Use gnudb.org as default cd database,
    as it is replacing Freedb
  * Translation updates: French, serbian
* Thu Jun  4 2020 aloisio@gmx.com
- Update to version 4.1.1
  * Patch from Till Bargheer: fix directory creation
  * Translation updates:
    Brazilian portuguese, danish, dutch, german
    italian, korean, norwegian, ukranian
- Drop 9c91b8.patch (merged upstream)
- Drop old source tarball
* Thu Feb 27 2020 Werner Fink <werner@suse.de>
- Add 9c91b8.patch to fix wromng directory access which leads to EACCESS
* Mon Feb 17 2020 Werner Fink <werner@suse.de>
- Update to version v4.1.0
  * Update gettext to 0.19.4.
  * Drop libgnomeui2 and libgnome2 dependencies
  * Fix out of source tree builds
  * Add meson as build system option
  * Fix application window icon
  * Restored short command-line options
  * Port to GtkStatusIcon and drop included EggTracyIcon code
  * Fix tray icon right-click menu positioning
  * Make -Werror optional (it does more harm than good)
  * Patch from Dan Fandrich:
    Stop copying overlapping strings on multi-artist CDs
  * Add korean translation from TP
  * nl.po, zh_CN.po: Update translations from TP
  * Patches from Adrian Reber:
  - Remove vte dependency
    grip uses vte for its status window. The version of vte grip relies on
    is not maintained upstream for a long time. This commit removes the
    complete status window functionality from grip. Messages previously sent
    to the status window are now sent to the console.
  - Switch to non-deprecated g_string functions
  - Ignore deprecation errors
  * Sync updated french translation from Translation Project
* Tue Mar 19 2019 enzokiel@kabelmail.de
- Update to version v3.10.1
  * Patch from Lutz Mändle: Calculates the correct space needed for
    drawing the labels in the edit box
  * Patch from Adrian Reber: Fix errors with gcc9 and terminate
    strings correctly
  version 3.10.0
  * Patch from Frédéric Fauberteau: undefined reference to
    `WIFEXITED' (patch issue #162)
  * Translation updates: New danish translation
  * Remove freedb.musicbrainz.org as secondary default cd database:
    https://blog.metabrainz.org/2018/09/18/freedb-gateway-end-of-life-notice-march-18-2019/
  * automake: Replace INCLUDES with AM_CPPFLAGS
  * Rename configure.in > configure.ac
* Wed Oct 10 2018 aloisio@gmx.com
- Update to version v3.9.0
  * Add freedb.musicbrainz.org as secondary default cd database
  version 3.8.1
  * Fedora patch: Search paths for executables during config
    switches
  * Reformat manpage, to ease maintanability
  * Add COPYING-LGPL: 4 files are licensed under the LGPLv2+
  * Sync Chinese (simplified) from Translatin Troject
  version 3.8.0
  * Add default encode configuration for
    + faac (bug #143)
    + opus (bug #117)
  * Fedora patch: put oggenc to the top of config list
    Apparently, without this patch, the config files are ignored
  version 3.7.1
  * Sync Spanish translation from Translation Project
  version 3.7.0
  * Sync Brazilian Portuguese from Translation Project
  * Patch by Phil Stracchino: extended genres to genre list
  version 3.6.3
  * Sync ukranian and hungarian translations from Translation
    Project
  * Patch from Adrian Reber: fix compiler warning with gcc 8.0
  * Update the FSF postal address in source files
  version 3.6.2
  * Translation updates: German, Italian, Brazilian Portuguese,
    Serbian
  version 3.6.1
  * Patch from Adrian Reber: fix compiler warning
    and enable -Werror and -Wall by default
  * Translation update: Norwegian
  version 3.6.0
  * Patch from Mike Gilbode: Select DiscDB entry from multiple
    results
  * Translation updates.
  version 3.5.2
  * Patch from Adrian Reber: Fix more compiler warnings
  version 3.5.1
  * Make icons transparent
  * Fix typo in userguide
  version 3.5.0
  * Apply Fedora patch from Adrian Reber (Fedora bug #1474010)
    The «blind-write-fix» patch from Mageia (originally from
    Mandriva in 2003) breaks Tagging of files other that MP3
  * Patch from Adrian Reber: Fix compiler warnings
  * Install manpage when running «make install»
  * Install grip-audiocd.desktop, which makes grip one of the
    popup options
    for ripping when inserting a CD in KDE/Plasma
  * Install icons into the hicolor tree
- Refreshed grip-configure.patch
* Thu Jul  6 2017 joerg.lorenzen@ki.tng.de
- Update to version 3.4.3
  + Add patch from Thomas Jaksch: Fix tray not ejecting.
* Wed Jul  5 2017 joerg.lorenzen@ki.tng.de
- Update to version 3.4.2
  + Add patch from Michael Stahl: add multi-artist file formats for
    rip and encode.
* Fri May 26 2017 joerg.lorenzen@ki.tng.de
- Update to version 3.4.1
  + v3.4.1 2017-05-25 Johnny A. Solbu <johnny@solbu.net>
  * Translation updates.
  * New translations: vietnamese and serbian.
  * Added switch to use artist's initial letter in filename.
  * Fix Improper handling of CDROM_AUDIO_INVALID (Thanks
    Tom Kelly). This hopefully fixes the inabillity to select
    another track, often one could only select track 1.
* Sun May 21 2017 joerg.lorenzen@ki.tng.de
- Switch to grip 3.4.0, development has moved from grip2 to grip
  + v3.4.0 2017-04-17 Johnny A. Solbu <johnny@solbu.net>
  * Patch from Vincent Chapman: Add option to invert directory
    slashes in m3u files.
  * Add «rip with grip» popup function (need to be manually
    added to the right place by distro packagers).
  * Fix «make dist» command
  - Don't include .gmo files.
  - Add manpage and grip-audiocd.desktop.
  + v3.3.5 2017-04-02 Johnny A. Solbu <johnny@solbu.net>
  * Add patches from Dr. Werner Fink.
  - Fix configure warnings.
  - Add missing declarations.
  * Update the file COPYING with an updated license text from
    fsf.org which have updated FSF postal addresses.
  * Updated translations: de, nl, pt_BR.
  * nb.po: Added Norwegian Bokmål translation.
* Wed Apr  5 2017 werner.fink@opensuse.org
- Switch over to grip2 3.3.4, one of the successors of former grip
  + v3.3.4 2017-01-17 Johnny A. Solbu <johnny@solbu.net>
  * Update ukranian translation, for real this time
  * Compile against current id3lib
  * Update links in documentation
  + v3.3.3 2017-01-03 Johnny A. Solbu <johnny@solbu.net>
  * uk.po: Added ukranian translation (Yuri Chornoivan)
  * ru.po: Updated (Alexey Loginov)
  * Fix crash: Grip crashed if translation was available
  * Add tray icon localization
  * Update documentation
  * Move installer instruction from README into the INSTALL file
  + v3.3.2 2016-12-30  Johnny A. Solbu <johnny@solbu.net>
  * de.po: Updated (Götz Waschk)
  * ru.po: Updated (Michael Shigorin)
  * es.po: Updated (Javier Fernandez-Sanguino)
  * Apply patches from Mageia
  - Increase minimal window width
  - Don't show warning window about development version
  - A few encoding patches
  - blind-write-fix
  * Added manpage
  * Apply patch from Arch-Linux: invalid-genre-size
  * Replace desktop file with an updated one from Mageia
  * Use xdg-open for opening the link in About tab
  * Switch default encoder from mp3 to ogg
  * Remove default comment tag
  * Change default encoding bitrate from 128 to 192 kbits
  * Dont require absolute paths for binaries
  * Fix possible buffer overflow when translated version string
    exceed 20 characters
  * Apply Debian patches
  - empty .m3u files are left around if «rip whole CD»
    dialog is cancelled
  - Add GNU/kFreeBSD support
  - fix ia64 segv
  * Apply fedora patches
  - Execute command after encode
  - fixed "_IO_fwrite: Process /usr/bin/grip was killed by signal 11"
  - no rip speed is indicated in the application
  - Fix resize errors
  + 2005-06-25  Mike Oliphant  <grip@nostatic.org>
  * de.po: updated (Götz Waschk)
  * it.po: updated (Ceoldo Costantino)
  * fr.po: updated (Eric Lassauge)
  * pl_PL.po: added (Piotr Adamocha)
  * id3.c: put a zero byte before the id3v1 track number (Vladimir
    Petrov)
  * discdb.c: string parsing fixes to support i18n (Vladimir Petrov)
  * discdb.c: better handling of non-UTF-8 local discdb files
    (Vladimir Petrov)
  * various: tweaks to filesystem-safe character escaping (Vladimir
    Petrov)
  * cdplay.c: allow retrieving of non-UTF-8 discdb entries (Vladimir
    Petrov)
  * discdb.c: fixed a possible buffer overflow crash (Dean Brettle)
  * grip.spec.in: added some missing BuildRequires (Stephen
    E. Dudek)
  * configure.in: upped version to 3.3.1
  + 2005-01-29  Mike Oliphant  <grip@nostatic.org>
  * nl.po: added (Sander Brabander)
  * hu.po: added (Ferenc Veres)
  * various: notification area support added
    (Christian Kirbach, Eoin Coffey)
  * grip.spec: fixed email address
  * rip.c: better error message if ripping is done with no disc in
    the drive (Markus Kaufhold)
  * rip.c/cdplay.c/discedit.c/grip.c/gripcfg.c: converted some
    warnings to use gnome_app_warning
  * various: notification area support added (Eoin Coffey)
  * discdb.c: fixed a problem keeping proxy support from working
    (Skip Slugger, lucabon)
  * discedit.c: do not show the multi-artist UI when no disc is
    present (Vladimir Petrov)
  * discedit.c: removed stray debugging when editing disc titile
    (Julian C. Dunn)
  * rip.c: fixed track number being off by one when auto-naming
    empty tracks (Vladimir Petrov)
  * configure.in: upped version to 3.3.0
* Sun Sep 26 2010 ro@suse.de
- grip-vte_adjustment.diff: fix build with current vte that does
  not directly expose the adjustment member any more
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Apr 15 2009 dmueller@suse.de
- refresh patches
* Thu Aug 23 2007 hvogel@suse.de
- Add hungarian translation [#295650]
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Thu Feb  8 2007 aj@suse.de
- Add c++ compiler to BuildRequires.
* Tue Feb  6 2007 sbrabec@suse.cz
- Reduced BuildRequires.
* Tue Jan 30 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Mon Nov 20 2006 hvogel@suse.de
- use desktop-launch instead of gnome-moz-remote to display
  web pages. [#222550]
* Sat Oct 28 2006 meissner@suse.de
- use RPM_OPT_FLAGS for CXXFLAGS too.
* Mon Mar 27 2006 bk@suse.de
- error handling done right needs more changes, keep only logging
- keep list of encoders in order to match config of other packges
* Thu Mar 23 2006 bk@suse.de
- fix badly broken spanish UTF-8 locale display
- fix error handling in out of disk space situations
- fix too low minimum bitrate assumption for flac encoding
- fix overlapping german labels (shortened too verbose labels)
- fix truncation of track name label in disc editor
* Wed Mar 22 2006 bk@suse.de
- 64bit: fix crash at start of encoding (wrong pointer signedness)
- fix stalled ripping and encoding speed meters on 64-bit systems
* Tue Mar 21 2006 bk@suse.de
- fix buffer overflow at startup in japanese environment (#132459)
* Mon Mar 20 2006 bk@suse.de
- fix creation of genre comment when creating ogg vorbis files
- fix creation of metadata information when creating flac files
- fix default setting of ID3 tags after mp3 files have been created
- fix truncation of rip column header string in the play/edit screen
- correct location of #ifdef CDIOCEJECT, fixes door unlocking for eject
- fix progress display when encoding using flac
- fixes from grip-3.3.1:
  fix track number being off by one when auto-naming empty tracks
  removed stray debugging when editing disc title
  better error message if ripping is done with no disc in the drive
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Mon Feb  6 2006 ro@suse.de
- fix build for < 10.1
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 hvogel@suse.de
- Make use of Stack Protector
* Wed Sep 14 2005 kukuk@suse.de
- Fix two buffer overflows
* Wed Jul  6 2005 hvogel@suse.de
- fix implicit functions
* Mon Apr  4 2005 mmj@suse.de
- don't return random data
* Wed Mar 30 2005 hvogel@suse.de
- fix two buffer overflows in the cddb handling (Bug #71933)
* Tue Sep 14 2004 meissner@suse.de
- Fixed proxy handling using curl (was completely broken). #44954
- Use OGG by default again. #45369
* Fri Aug 27 2004 clahey@suse.de
- Cache grip help and show grip in khelpcenter.
* Mon Aug  2 2004 ro@suse.de
- recode desktop file to utf-8
* Mon May  3 2004 meissner@suse.de
- Upgraded to 3.2.0. Disabled ogg patch for now.
* Thu Apr  1 2004 meissner@suse.de
- Set default encoder to oggenc, default ext. to .ogg,
  since we do not ship mp3 stuff.
* Mon Feb 16 2004 meissner@suse.de
- Upgraded to 3.1.4.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Oct  9 2003 meissner@suse.de
- upgraded to 3.1.2, add docu build, added vte, vte-devel.
* Mon Sep 29 2003 meissner@suse.de
- Upgraded to 3.1.1.
* Sat Aug 16 2003 adrian@suse.de
- add Categories
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 20 2003 ro@suse.de
- fix build with gettext
* Sun Mar  2 2003 meissner@suse.de
- added resmgr to neededforbuild (cdparanoia needs it)
* Thu Feb  6 2003 meissner@suse.de
- Added documentation generating neededforbuilds etc.
* Wed Feb  5 2003 meissner@suse.de
- update -> 3.0.5
  Translations (de, ja, ru) and documentation were updated. A
  problem was fixed that caused disc lookups to fail on some systems.
  Several minor ripping bugs were fixed.
* Thu Jan  9 2003 meissner@suse.de
- update -> 3.0.4
* Mon Sep 30 2002 uli@suse.de
- update -> 3.0.3
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Tue Jul  2 2002 meissner@suse.de
- rerun auto* tools, buildrootet.
* Mon Jun 10 2002 uli@suse.de
- update -> 3.0.0
* Mon Aug 13 2001 uli@suse.de
- initial package
